@@ -1,6 +1,6 @@
 package SWISH::API;
 
-# $Id: API.pm,v 1.7.2.2 2003/12/16 14:37:38 whmoseley Exp $
+# $Id: API.pm,v 1.7.2.4 2004/01/24 18:26:45 whmoseley Exp $
 
 require DynaLoader;
 
@@ -69,7 +69,7 @@ SWISH::API - Perl interface to the Swish-e C Library
             $result->Property( "swishdocsize" ),
             $result->Property( "swishtitle" ),
             $result->Property( "swishdbfile" ),
-            $result->Property( "swishlastmodified" ),
+            $result->ResultPropertyStr( "swishlastmodified" ),
             $result->Property( "swishreccount" ),
             $result->Property( "swishfilenum" )
         );
@@ -395,9 +395,24 @@ The follow methods provide access to data related to an individual result.
 
 =over 4
 
-=item $prop = $result->property( $prop_name );
+=item $prop = $result->Property( $prop_name );
 
 Fetches the property specified for the current result.
+An invalid property name will cause an exception (which can be caught
+by wrapping the call in an eval block).
+
+Can return undefined.
+
+Date properties are returned as a timestamp.  Use something like Date::Format to
+format the strings (or just call scalar localtime( $prop ) ).
+
+=item $prop = $result->ResultPropertyStr( $prop_name );
+
+Fetches and formats the property.  Unlike above, invalid property names return the
+string "(null)" -- this will likely change to match the above (i.e. throw an exception).
+
+Undefined values are returned at the null string ("").
+
 
 =item $value = $result->ResultIndexValue( $header_name );
 
@@ -413,11 +428,11 @@ $swish->HeaderValue(), but the index file is not specified
 
 =item $stemmed_word = $swish->StemWord( $word );
 
-*Depreciated*
+*Deprecated*
 
 Returns the stemmed version of the passed in word.
 
-Depreciated because only stems using the original Porter Stemmer
+Deprecated because only stems using the original Porter Stemmer
 and uses a shared memory location in the SW_HANDLE object to store the stemmed
 word.  See below for other stemming options.
 
