@@ -1,5 +1,5 @@
 /*
-$Id: entities.c,v 1.17 2003/03/28 16:31:31 whmoseley Exp $
+$Id: entities.c,v 1.17.2.1 2003/12/23 15:26:43 whmoseley Exp $
 **
 ** This program and library is free software; you can redistribute it and/or
 ** modify it under the terms of the GNU (Library) General Public License
@@ -634,7 +634,7 @@ int     charEntityDecode(unsigned char *s, unsigned char **end)
 {
     unsigned char *s1,
            *t;
-    unsigned char *e_end;
+    char *e_end;
     unsigned char s_cmp[MAX_ENTITY_LEN + 1];
     int     len;
     int     code;
