@@ -1,5 +1,5 @@
 /*
-$Id: index.c,v 1.222.2.3 2003/12/14 01:26:55 whmoseley Exp $
+$Id: index.c,v 1.222.2.4 2004/01/30 19:47:17 whmoseley Exp $
 **
 ** Copyright (C) 1995, 1996, 1997, 1998 Hewlett-Packard Company
 ** Originally by Kevin Hughes, kev@kevcom.com, 3/11/94
@@ -141,8 +141,9 @@ $Id: index.c,v 1.222.2.3 2003/12/14 01:26:55 whmoseley Exp $
 static void index_path_parts( SWISH *sw, char *path, path_extract_list *list, INDEXDATAHEADER *header, docProperties **properties );
 static void SwapLocData(SWISH *,ENTRY *,unsigned char *,int);
 static void unSwapLocData(SWISH *,int, ENTRY *);
+#ifndef USE_BTREE
 static void sortSwapLocData(ENTRY *);
-
+#endif
 
 /* 
   -- init structures for this module
@@ -2138,7 +2139,7 @@ void    write_index(SWISH * sw, IndexFILE * indexf)
             /* If exists, we have to add the new worddata buffer to the old one */
             if(old_wordid)
             {
-                 add_worddata(indexf, buffer, sz_buffer);
+                 add_worddata(sw, buffer, sz_buffer);
                  efree(buffer);
                  buffer = NULL;
                  sz_buffer = 0;
@@ -2894,6 +2895,7 @@ static void unSwapLocData(SWISH * sw, int idx_swap_file, ENTRY *ep)
     }
 }
 
+#ifndef USE_BTREE
 /* 2002-07 jmruiz - Sorts unswaped location data by metaname, filenum */
 static void sortSwapLocData(ENTRY *e)
 {
@@ -2972,5 +2974,6 @@ static void sortSwapLocData(ENTRY *e)
 
     /* Free the memory of the sorting array */
     efree(ptmp);
-                 
+
 }
+#endif
