@@ -1,5 +1,5 @@
 /*
-$Id: parse_conffile.c,v 1.93.2.1 2003/12/13 05:26:46 whmoseley Exp $
+$Id: parse_conffile.c,v 1.93.2.2 2004/03/09 18:17:55 whmoseley Exp $
 **
 ** Copyright (C) 1995, 1996, 1997, 1998 Hewlett-Packard Company
 ** Originally by Kevin Hughes, kev@kevcom.com, 3/11/94
@@ -431,31 +431,9 @@ void    getdefaults(SWISH * sw, char *conffile, int *hasdir, int *hasindex, int
         
         if (strcasecmp(w0, "UseStemming") == 0)
         {
-#ifdef SNOWBALL
-            char *stem_tmp;
-            if (sl->n != 2)
-                progerr("%s: requires one value", w0);
-
-            /* Fix. "no" should default to norvegian
-            if( strcasecmp(sl->word[1],"no") != 0 )
-            {
-            */
-                /* Fix to make "UseStemming yes" -> "UseStemming en" */
-                if( strcasecmp(sl->word[1],"yes") == 0 )
-                    strcpy(sl->word[1],"en");
-
-                stem_tmp = (char *) emalloc(strlen("Stemming_") + strlen(sl->word[1]) + 1);
-                sprintf(stem_tmp,"Stemming_%s",sl->word[1]);
-                fuzzy_or_die( indexf, stem_tmp );
-
-                efree(stem_tmp);
-            /*
-            }
-            */
-#else
+            progwarn("UseStemming is deprecated.  See FuzzyIndexingMode in the docs");
             if ( getYesNoOrAbort(sl, 1, 1) )
                 fuzzy_or_die( indexf, "Stemming_en" );
-#endif
                     
             continue;
         }
