@@ -1,5 +1,5 @@
 /*
-** $Id: swish.h,v 1.190.2.1 2003/12/13 05:26:46 whmoseley Exp $
+** $Id: swish.h,v 1.190.2.2 2004/01/30 19:47:18 whmoseley Exp $
 **
 ** Copyright (C) 1995, 1996, 1997, 1998 Hewlett-Packard Company
 ** Originally by Kevin Hughes, kev@kevcom.com, 3/11/94
@@ -138,7 +138,13 @@ extern "C" {
 #endif
 
 
+/* $$$ THESE NEED TO BE UPGRADED WHEN THE INDEX FORMAT CHANGES */
+
+#ifdef USE_BTREE
+#define SWISH_MAGIC 11076322L
+#else
 #define SWISH_MAGIC 21076322L
+#endif
 
 #define INDEXFILE "index.swish-e"
 
